/*
------------------------------------------------------------------
Provider:  Zip-Codes.com
Product:   Canadian Postal Code Database Deluxe
------------------------------------------------------------------
This SQL Creates a new table named PostalCodes, 
related indexes, and extended column information.

This script is designed to work with MS SQL Server 2000 & 2005

Actions:
  1.) Drop Table PostalCodes if it exists
  2.) Creates Table named PostalCodes
  3.) Creates Indexes on table PostalCodes
  4.) Creates Extended Column Information

Last Updated: 6/24/2008
------------------------------------------------------------------
*/


/* 1.) Drop Table if it Exists */
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[PostalCodes]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table [dbo].[PostalCodes]
GO


/* 2.) Create Table */
CREATE TABLE [dbo].[PostalCodes] (
	[PostalCode] [char] (7) NOT NULL,
	[City] [varchar] (45),
	[Province] [char] (2),
	[ProvinceName] [varchar] (45),
	[AreaCode] [varchar] (3),
	[CityFlag] [char] (1),
	[TimeZone] [int],
	[DST] [char] (1),
	[Latitude] [decimal](18, 6),
	[Longitude] [decimal](18, 6),
	[Elevation] [int],
	[Population] [int],
	[Dwellings] [int],
) ON [PRIMARY]
GO


/* 3.) Create Indexes on most searched fields */
CREATE  INDEX [Index_PostalCodes_PostalCode]			 ON [dbo].[PostalCodes]([PostalCode]) ON [PRIMARY]
CREATE  INDEX [Index_PostalCodes_Province]				 ON [dbo].[PostalCodes]([Province]) ON [PRIMARY]
CREATE  INDEX [Index_PostalCodes_AreaCode]				 ON [dbo].[PostalCodes]([AreaCode]) ON [PRIMARY]
CREATE  INDEX [Index_PostalCodes_City]					 ON [dbo].[PostalCodes]([City]) ON [PRIMARY]
CREATE  INDEX [Index_PostalCodes_Latitude]				 ON [dbo].[PostalCodes]([Latitude]) ON [PRIMARY]
CREATE  INDEX [Index_PostalCodes_Longitude]				 ON [dbo].[PostalCodes]([Longitude]) ON [PRIMARY]
GO


/* 4.) Create Extended Column Information */
exec sp_addextendedproperty N'MS_Description', N'Canadian Postal Code Database  Deluxe (from www.zip-codes.com)', N'user', N'dbo', N'table', N'PostalCodes'
exec sp_addextendedproperty N'MS_Description', N'The Postal Code of the record in ANA NAN format.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'PostalCode'
exec sp_addextendedproperty N'MS_Description', N'The name of the city, town or village of the Postal Code.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'City'
exec sp_addextendedproperty N'MS_Description', N'The two-letter abbreviation for the province to that Postal Code.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'Province'
exec sp_addextendedproperty N'MS_Description', N'The name of the province to that Postal Code.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'ProvinceName'
exec sp_addextendedproperty N'MS_Description', N'The telephone area code for this Postal Code.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'AreaCode'
exec sp_addextendedproperty N'MS_Description', N'Yes/No flag indicating if the Postal Code is in a City.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'CityFlag'
exec sp_addextendedproperty N'MS_Description', N'The time Zone Number for which this Postal Code belongs to.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'TimeZone'
exec sp_addextendedproperty N'MS_Description', N'Indicates whether they observe Day Light Savings Time.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'DST'
exec sp_addextendedproperty N'MS_Description', N'Geographic coordinate measured in degrees north or south of the equater.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'Latitude'
exec sp_addextendedproperty N'MS_Description', N'Geographic coordinate measured in degrees east or wets of the Greenwich Meridian.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'Longitude'
exec sp_addextendedproperty N'MS_Description', N'Average elevation of the Postal Code in meters.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'Elevation'
exec sp_addextendedproperty N'MS_Description', N'The population count for the Forward Sortation Area by Canadian Census 2006.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'Population'
exec sp_addextendedproperty N'MS_Description', N'The total number of private dwellings count for the Forward Sortation Area by Canadian Census 2006.', N'user', N'dbo', N'table', N'PostalCodes', N'column', N'Dwellings'

GO